SystemOrganization addCategory: #'SBlog-Model'!
SystemOrganization addCategory: #'SBlog-Tests'!
SystemOrganization addCategory: #'SBlog-UI'!

WAComponent subclass: #BlogEditor
	instanceVariableNames: 'author blog '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:43'!
addEntry
	| entry |
	entry _ BlogEntry blog: blog author: author.
	(self call: (BlogEntryEditor new entry: entry)) ifTrue: [entry post].! !

!BlogEditor methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 21:59'!
renderEntry: aBlogEntry on: html
	html paragraph: [
		html bold: aBlogEntry title.
		html text: ' , '.
		html italic: (aBlogEntry category ifNil: [''] ifNotNil: [aBlogEntry category asString]).
		html space; space; space.
		html anchorWithAction: [self call: (BlogEntryEditor new entry: aBlogEntry)] text: 'Edit'.
		html blockquote: aBlogEntry text.
	]! !

!BlogEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:23'!
author: anAuthor
	author _ anAuthor! !

!BlogEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:46'!
renderContentOn: html
	html heading: blog name level: 3.
	html anchorWithAction: [self addEntry] text: 'Add Entry'.
	
	blog entries do:
		[:ea |
		self renderEntry: ea on: html].! !

!BlogEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:23'!
blog: aBlog
	blog _ aBlog! !

WAComponent subclass: #BlogList
	instanceVariableNames: 'author blogName '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogList methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:36'!
renderContentOn: html
	html bold: 'Blogs:'.
	html table: [
		author blogs do:
			[:ea |
			self renderRowForBlog: ea on: html].
	].
	html paragraph.
	html form: [
		html bold: 'Create blog: '.
		html textInputWithValue: '' callback: [:v | blogName _ v].
		html submitButtonWithAction: [self createBlog] text: 'OK'. 
	]! !

!BlogList methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:45'!
createBlog
	blogName isEmpty ifFalse: [author createBlogNamed: blogName]! !

!BlogList methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:30'!
renderRowForBlog: aBlog on: html
	html tableRow: [
		html tableData: [
			html anchorWithAction: [self chooseBlog: aBlog] text: aBlog name.
		]
	]! !

!BlogList methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:30'!
author: anAuthor
	author _ anAuthor! !

!BlogList methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:42'!
chooseBlog: aBlog
	self call: (BlogEditor new blog: aBlog; author: author)! !

WAComponent subclass: #BlogLogin
	instanceVariableNames: 'username password '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogLogin methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 12:58'!
renderContentOn: html
	html form: [
		html table: [
			html tableRowWithLabel: 'Username:' column: [
				html textInputWithValue: username callback: [:v | username _ v].
			].
			html tableRowWithLabel: 'Password:' column: [
				html passwordInputWithCallback: [:v | password _ v].
			].
			html attributes alignCenter.
			html tableRowWith: [
				html submitButtonWithAction: [self login] text: 'Login'
			] span: 2.
		].
	]! !

!BlogLogin methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:05'!
findAuthor
	| author |
	author _ self session store authors detect: [:ea | ea username = username] ifNone: [^ nil].
	^ (author checkPassword: password) ifTrue: [author]! !

!BlogLogin methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:06'!
login
	self findAuthor ifNotNilDo: [:a | self answer: a].
	! !

WAComponent subclass: #BlogAuthorFrame
	instanceVariableNames: 'author main '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogAuthorFrame methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:17'!
renderRowForBlog: aBlog on: html
	html tableRow: [
		html tableData: [
			html anchorWithAction: [self chooseBlog: aBlog] text: aBlog name.
		]
	]! !

!BlogAuthorFrame methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:36'!
renderContentOn: html
	html bold: author username.
	html space.
	html anchorWithAction: [self answer] text: 'logout'.
	html paragraph.
	html render: main! !

!BlogAuthorFrame methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:35'!
author: anAuthor
	author _ anAuthor.
	main _ BlogList new author: anAuthor.! !

WAComponent subclass: #BlogViewer
	instanceVariableNames: 'blogHolder '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 01:35'!
renderContentOn: html
	self blog entries do: [:ea | self renderEntry: ea on: html]! !

!BlogViewer methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 16:07'!
renderEntry: aBlogEntry on: html
	html paragraph: [
		html bold: aBlogEntry title.
		html blockquote: (aBlogEntry category ifNil: [''] ifNotNil: [aBlogEntry category asString]).
		html blockquote: aBlogEntry text.
	]! !

!BlogViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 00:18'!
blogHolder: aBlogHolder
	blogHolder _ aBlogHolder! !

!BlogViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 00:18'!
blog
	^ blogHolder contents! !

WAComponent subclass: #BlogEntryEditor
	instanceVariableNames: 'entry '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 01:40'!
ok
	self answer: true! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 21:36'!
renderContentOn: html
	html form: [
		html text: 'Title: '.
		html textInputOn: #title of: entry.
		html space.
		html text: 'Category: '.
		html selectFromList: self allCategories selected: entry category callback: (MessageSend receiver: self selector: #category:).
		html space.
		html text: 'or'.
		html space.
		html textInputWithCallback: (MessageSend receiver: self selector: #category:).
		html break.
		html textAreaOn: #text of: entry.
		html break.
		html submitButtonOn: #ok of: self.
		html space.
		html submitButtonOn: #cancel of: self. 
	]! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 15:40'!
style
	^'
		body{
			background:#f6f6f6;
			color:#000000;
     		font-family:"Trebuchet MS",Trebuchet,Verdana,Sans-Serif;
     	}
		a{color:#800080;}
		a:hover{color:#E0AD12;}
	'! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 01:35'!
entry: aBlogEntry
	entry _ aBlogEntry! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 01:40'!
cancel
	self answer: false! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 16:10'!
allCategories

	^entry allCategories asSortedCollection! !

!BlogEntryEditor methodsFor: 'as yet unclassified' stamp: 'btb 10/13/2003 21:33'!
category: aString

	aString ifNil: [^self].
	aString ifEmpty: [^self].
	entry category: aString.! !

WAControllerSession subclass: #BlogSession
	instanceVariableNames: 'store '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogSession methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 12:52'!
initialize
	super initialize.
	store _ BlogStore new.
	self setUpSampleData.! !

!BlogSession methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 12:43'!
store
	^ store! !

!BlogSession methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 12:52'!
setUpSampleData
	| author |
	author _ store createAuthorWithUsername: 'joe' password: 'blow'.
	author createBlogNamed: 'Joe''s Blog'.! !

TestCase subclass: #BlogTest
	instanceVariableNames: 'store '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Tests'!

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:53'!
testCreateBlogForAuthor
	| author blog |
	author _ store createAuthorWithUsername: 'bob' password: 'foo'.
	blog _ author createBlogNamed: 'bob''s blog'.
	self assert: author blogs size = 1.
	self assert: author blogs anyOne = blog.
	self assert: blog authors size = 1.
	self assert: blog authors anyOne = author.! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:55'!
testAbandonEntry
	| author blog entry |
	author _ store createAuthorWithUsername: 'bob' password: 'foo'.
	blog _ author createBlogNamed: 'bob''s blog'.
	entry _ BlogEntry blog: blog author: author.
	entry _ nil.
	self assert: blog entries isEmpty! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/12/2003 00:02'!
testPostEntryWithoutPermission
	| author blog entry author2 |
	author _ store createAuthorWithUsername: 'bob' password: 'foo'.
	blog _ author createBlogNamed: 'bob''s blog'.
	author2 _ store createAuthorWithUsername: 'john' password: 'bar'.
	entry _ BlogEntry blog: blog author: author2.
	self should: [entry post] raise: Error.
	self assert: blog entries isEmpty! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:39'!
testCreateBlog
	| blog |
	blog _ store createBlogNamed: 'blog1'.
	self assert: blog name = 'blog1'.
	self assert: blog authors isEmpty.
	self assert: blog entries isEmpty! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:36'!
setUp
	store _ BlogStore new! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:55'!
testPostEntry
	| author blog entry |
	author _ store createAuthorWithUsername: 'bob' password: 'foo'.
	blog _ author createBlogNamed: 'bob''s blog'.
	entry _ BlogEntry blog: blog author: author.
	(Delay forSeconds: 2) wait.
	entry post.
	self assert: blog entries size = 1.
	self assert: blog entries anyOne = entry.
	self assert: Time now seconds = entry time seconds.! !

!BlogTest methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:38'!
testCreateAuthor
	| author |
	author _ store createAuthorWithUsername: 'bob' password: 'foo'.
	self assert: author username = 'bob'.
	self assert: (author checkPassword: 'foo').
	self deny: (author checkPassword: 'fooz').
	self assert: author blogs isEmpty
	! !

Object subclass: #BlogStorable
	instanceVariableNames: 'store '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Model'!

!BlogStorable methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:25'!
store
	^store! !

!BlogStorable class methodsFor: 'as yet unclassified' stamp: 'btb 10/12/2003 16:26'!
newWithStore: aStore

	^self basicNew initializeWithStore: aStore! !

!BlogStorable methodsFor: 'private' stamp: 'btb 10/12/2003 16:27'!
initializeWithStore: aBlogStore

	self store: aBlogStore! !

BlogStorable subclass: #BlogAuthor
	instanceVariableNames: 'username passwordHash '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Model'!

!BlogAuthor methodsFor: 'admin' stamp: 'btb 10/12/2003 16:33'!
createBlogNamed: aString
	| blog |
	blog _ self store createBlogNamed: aString.
	blog addAuthor: self.
	^ blog! !

!BlogAuthor methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:08'!
username
	^ username! !

!BlogAuthor class methodsFor: 'as yet unclassified' stamp: 'btb 10/12/2003 16:33'!
username: nameString password: passwordString store: aBlogStore
	^ (self newWithStore: aBlogStore) 
		initializeWithUsername: nameString password: passwordString! !

!BlogAuthor methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:33'!
blogs
	"a list of all of the blogs this author can post to"
	^ self store blogs select: [:ea | ea acceptsPostsFromAuthor: self]! !

!BlogAuthor methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:07'!
hashPassword: aString
	^ SecureHashAlgorithm new hashStream: (ReadStream on: aString) ! !

!BlogAuthor methodsFor: 'initializing' stamp: 'btb 10/12/2003 16:33'!
initializeWithUsername: nameString password: passwordString
	username _ nameString.
	passwordHash _ self hashPassword: passwordString.! !

!BlogAuthor methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:38'!
checkPassword: aString
	"return true if aString matches this author's password"
	^ (self hashPassword: aString) = passwordHash! !

!BlogStorable methodsFor: 'private-accessing' stamp: 'btb 10/12/2003 16:25'!
store: anObject
	store := anObject! !

BlogStorable subclass: #BlogEntry
	instanceVariableNames: 'blog author date time title text id category '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Model'!

!BlogEntry class methodsFor: 'as yet unclassified' stamp: 'btb 10/12/2003 16:30'!
blog: aBlog author: anAuthor store: aStore
	^ (self newWithStore: aStore) 
			initializeWithBlog: aBlog author: anAuthor! !

!BlogEntry class methodsFor: 'as yet unclassified' stamp: 'btb 10/12/2003 16:32'!
blog: aBlog author: anAuthor
	^ self blog: aBlog author: anAuthor store: aBlog store! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:31'!
text: aString
	text _ aString! !

!BlogEntry methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:54'!
category

	^category! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:42'!
author
	^ author! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:31'!
title: aString
	title _ aString! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/12/2003 00:03'!
time
	"time this entry was created"
	^ time! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/12/2003 00:03'!
date
	"date this entry was created"
	^ date! !

!BlogEntry methodsFor: 'accessing' stamp: 'btb 10/13/2003 16:39'!
category: aString

	category _ aString.
	self blog addCategory: aString.! !

!BlogEntry methodsFor: 'initializing' stamp: 'avi 10/11/2003 23:41'!
initializeWithBlog: aBlog author: anAuthor
	blog _ aBlog.
	author _ anAuthor.
	title _ 'Untitled'.
	text _ ''! !

!BlogEntry methodsFor: 'posting' stamp: 'btb 10/12/2003 16:55'!
post
	date _ Date today.
	time _ Time now.
	blog postEntry: self.! !

!BlogEntry methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:50'!
id: anObject
	id _ anObject! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/12/2003 00:03'!
title
	"the title of the entry"
	^ title! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/12/2003 00:03'!
text
	"the full text of the entry"
	^ text! !

!BlogEntry methodsFor: 'accessing' stamp: 'avi 10/12/2003 00:03'!
blog
	"the blog this entry was posted to"
	^ blog! !

!BlogEntry methodsFor: 'accessing' stamp: 'btb 10/13/2003 16:09'!
allCategories

	^self blog categories! !

!BlogEntry methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:41'!
id
	^id! !

BlogStorable subclass: #Blog
	instanceVariableNames: 'name entries authors categories nextEntryId '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Model'!

!Blog class methodsFor: 'as yet unclassified' stamp: 'btb 10/12/2003 16:35'!
name: aString store: aBlogStore
	^ (self newWithStore: aBlogStore) initializeWithName: aString! !

!Blog methodsFor: 'convience' stamp: 'btb 10/12/2003 17:02'!
entriesWithCategory: aString

	^self entries select: [:eachEntry | eachEntry category = aString]! !

!Blog methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:17'!
name
	"the full name of the blog"
	^ name! !

!Blog methodsFor: 'posting' stamp: 'btb 10/12/2003 16:57'!
postEntry: anEntry
	(self acceptPost: anEntry)
		ifTrue: [entries add: anEntry.
				anEntry id: self generateNextEntryId]
		ifFalse: [self error: 'Unauthorized posting']! !

!Blog methodsFor: 'admin' stamp: 'avi 10/11/2003 23:52'!
addAuthor: anAuthor
	authors add: anAuthor! !

!Blog methodsFor: 'accessing' stamp: 'avi 10/12/2003 02:00'!
entries
	"every entry ever posted to the blog, newest first"
	^ entries asSortedCollection: [:a :b | a date > b date or: [a date = b date and: [a time >= b time]]]! !

!Blog methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:50'!
authors
	"the list of authors allowed to post to this blog"
	^ authors! !

!Blog methodsFor: 'private-accessing' stamp: 'btb 10/12/2003 17:00'!
nextEntryId
	^nextEntryId! !

!Blog methodsFor: 'private' stamp: 'btb 10/12/2003 16:59'!
generateNextEntryId

	| result |
	result _ self nextEntryId.
	self nextEntryId: (result + 1).
	^result! !

!Blog methodsFor: 'convience' stamp: 'btb 10/12/2003 16:52'!
addCategory: aString

	self categories add: aString! !

!Blog methodsFor: 'private' stamp: 'btb 10/13/2003 16:10'!
initializeCategories

	categories _ Set new.
	categories 
		add: 'Squeak';
		add: 'Smalltalk';
		add: 'Music';
		add: 'Etc'! !

!Blog methodsFor: 'testing' stamp: 'avi 10/11/2003 23:51'!
acceptPost: aPost
	^ self acceptsPostsFromAuthor: aPost author! !

!Blog methodsFor: 'private-accessing' stamp: 'btb 10/12/2003 17:00'!
nextEntryId: anObject
	nextEntryId := anObject! !

!Blog methodsFor: 'accessing' stamp: 'btb 10/12/2003 16:48'!
categories

	^categories! !

!Blog methodsFor: 'initializing' stamp: 'btb 10/13/2003 14:52'!
initializeWithName: aString
	name _ aString.
	entries _ Set new.
	authors _ Set new.
	self initializeCategories.
	self nextEntryId: 0.! !

!Blog methodsFor: 'convience' stamp: 'btb 10/12/2003 16:52'!
removeCategory: aString

	self categories remove: aString! !

!Blog methodsFor: 'testing' stamp: 'avi 10/11/2003 23:51'!
acceptsPostsFromAuthor: anAuthor
	^ authors includes: anAuthor! !

Object subclass: #BlogStore
	instanceVariableNames: 'blogs authors permissions '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-Model'!

!BlogStore methodsFor: 'initializing' stamp: 'avi 10/11/2003 23:47'!
initialize
	blogs _ Set new.
	authors _ Set new.
	permissions _ Dictionary new! !

!BlogStore methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:25'!
createAuthorWithUsername: username password: password
	| author |
	author _ BlogAuthor username: username password: password store: self.
	authors add: author.
	^ author	! !

!BlogStore methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:19'!
authors
	^ authors! !

!BlogStore class methodsFor: 'as yet unclassified' stamp: 'avi 10/11/2003 23:18'!
new
	^ self basicNew initialize! !

!BlogStore methodsFor: 'admin' stamp: 'avi 10/11/2003 23:26'!
createBlogNamed: aString
	| blog |
	blog _ Blog name: aString store: self.
	blogs add: blog.
	^ blog! !

!BlogStore methodsFor: 'accessing' stamp: 'avi 10/11/2003 23:19'!
blogs
	^ blogs! !

WATask subclass: #BlogLoginTask
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SBlog-UI'!

!BlogLoginTask class methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:06'!
initialize
	self registerAsApplication: 'sblog' sessionClass: BlogSession! !

!BlogLoginTask methodsFor: 'as yet unclassified' stamp: 'avi 10/13/2003 13:24'!
go
	| author |
	author _ self call: (BlogLogin new).
	self session isolate: [self call: (BlogAuthorFrame new author: author)]! !
BlogLoginTask initialize!
